pub enum ToolkitError {
CircuitOpen {
retry_after: Duration,
},
BulkheadClosed,
RetryExhausted {
attempts: u32,
},
}Expand description
Errors that can be returned by reliability primitives themselves (as opposed to errors from the wrapped operation).
Variants
CircuitOpen
The circuit breaker is currently open and rejected the call without invoking it.
BulkheadClosed
The bulkhead has been closed and is no longer accepting permits.
RetryExhausted
Retry exhausted its attempt budget without a success.